@@ -1,4 +1,4 @@
-# copyright 2019-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2019-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -25,14 +25,12 @@ from pyramid.view import view_config
 
 from cubicweb.pyramid.auth import CWAuthTktAuthenticationPolicy
 
-from cubicweb_saml.utils import (get_user,
-                                 on_register_user,
-                                 retrieve_url_from_client)
+from cubicweb_saml.utils import get_user, on_register_user, retrieve_url_from_client
 
 
-@view_config(route_name='saml', require_csrf=False)
+@view_config(route_name="saml", require_csrf=False)
 def saml(request):
-    """ Manage SAML requests and show an error message when the SAML user is
+    """Manage SAML requests and show an error message when the SAML user is
     not available in cubicweb.
 
     For each utils methods like get_user, the client identity is check to
@@ -52,37 +50,36 @@ def saml(request):
         If there is no SAML response, redirect to the CubicWeb base URL
     """
 
-    if request.POST and 'SAMLResponse' in request.POST:
-        config = request.registry['cubicweb.config']
+    if request.POST and "SAMLResponse" in request.POST:
+        config = request.registry["cubicweb.config"]
 
         userid = get_user(request)
 
-        if userid is None and config.get('saml-register-unknown-user', False):
+        if userid is None and config.get("saml-register-unknown-user", False):
             userid = on_register_user(request)
 
         if userid:
-            relay_state = request.POST.get('RelayState', '')
+            relay_state = request.POST.get("RelayState", "")
 
             # Make sure not to redirect to another website
-            if not relay_state.startswith(config['base-url']):
-                relay_state = config['base-url']
+            if not relay_state.startswith(config["base-url"]):
+                relay_state = config["base-url"]
 
-            raise HTTPSeeOther(location=relay_state,
-                               headers=remember(request, userid))
+            raise HTTPSeeOther(location=relay_state, headers=remember(request, userid))
 
         request.cw_request.set_message(
-            request.cw_request._('Authentication with SAML failed.'))
+            request.cw_request._("Authentication with SAML failed.")
+        )
         request.response.status_code = 403
-        raise HTTPSeeOther(location=request.cw_request.build_url('login'))
+        raise HTTPSeeOther(location=request.cw_request.build_url("login"))
 
-    raise HTTPSeeOther(location=request.cw_request.build_url(''))
+    raise HTTPSeeOther(location=request.cw_request.build_url(""))
 
 
 @implementer(IAuthenticationPolicy)
 class SAMLAuthenticationPolicy(CWAuthTktAuthenticationPolicy):
-
     def authenticated_userid(self, request):
-        """ Return the authenticated userid or None if no authenticated userid
+        """Return the authenticated userid or None if no authenticated userid
         can be found. This method of the policy should ensure that a record
         exists in whatever persistent store is used related to the user (the
         user should not have been deleted); if a record associated with the
@@ -109,18 +106,17 @@ class SAMLAuthenticationPolicy(CWAuthTktAuthenticationPolicy):
         cubicweb.pyramid.auth.CWAuthTktAuthenticationPolicy.authenticated_userid
         """
 
-        if '__login' in request.POST and not request.POST.get('__login', ''):
-            config = request.registry['cubicweb.config']
+        if "__login" in request.POST and not request.POST.get("__login", ""):
+            config = request.registry["cubicweb.config"]
 
-            if 'SAMLResponse' not in request.POST:
-                raise HTTPSeeOther(
-                    location=retrieve_url_from_client(config, request))
+            if "SAMLResponse" not in request.POST:
+                raise HTTPSeeOther(location=retrieve_url_from_client(config, request))
 
             userid = get_user(request)
             if userid:
                 return str(userid)
 
-            elif config.get('saml-register-unknown-user', False):
+            elif config.get("saml-register-unknown-user", False):
                 userid = on_register_user(request)
                 if userid:
                     return str(userid)
