@@ -1,4 +1,4 @@
-# copyright 2021-2021 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
+# copyright 2021-2022 LOGILAB S.A. (Paris, FRANCE), all rights reserved.
 # contact http://www.logilab.fr -- mailto:contact@logilab.fr
 #
 # This program is free software: you can redistribute it and/or modify it under
@@ -27,11 +27,10 @@ from cubicweb_saml.utils import retrieve_url_from_client
 
 
 class SAMLLogMixin:
-    """ Mixin class used to manage log-related templates
-    """
+    """Mixin class used to manage log-related templates"""
 
     def get_saml_uri_from_request(self, request):
-        """ Retrieve the SAML URI based on receiving request
+        """Retrieve the SAML URI based on receiving request
 
         Parameters
         ----------
@@ -47,8 +46,7 @@ class SAMLLogMixin:
         return retrieve_url_from_client(self._cw.vreg.config, request)
 
     def on_activate_saml(self):
-        """ Retrieve and redirect to SAML URI
-        """
+        """Retrieve and redirect to SAML URI"""
 
         uri = self.retrieve_saml_uri()
 
@@ -56,7 +54,7 @@ class SAMLLogMixin:
             self.redirect_to(uri)
 
     def redirect_to(self, uri):
-        """ Redirect user to a dedicated URI
+        """Redirect user to a dedicated URI
 
         Parameters
         ----------
@@ -71,12 +69,12 @@ class SAMLLogMixin:
 
         # Show a link on webpage in case of the redirection is not allowed in
         # web browser
-        self.w(a('Redirect to SAML IdP...', href=uri))
+        self.w(a("Redirect to SAML IdP...", href=uri))
 
         raise HTTPSeeOther(location=uri)
 
     def retrieve_saml_uri(self):
-        """ Retrieve the SAML URI if sources has been correctly defined
+        """Retrieve the SAML URI if sources has been correctly defined
 
         Returns
         -------
@@ -86,7 +84,7 @@ class SAMLLogMixin:
 
         sources = self._cw.vreg.config.read_sources_file()
 
-        metadata_uri = sources.get('saml', {}).get('saml-metadata-uri', None)
+        metadata_uri = sources.get("saml", {}).get("saml-metadata-uri", None)
         if metadata_uri is None:
             return None
 
@@ -95,16 +93,18 @@ class SAMLLogMixin:
         # Add fake login form data to current request to start SAML connection
         # correctly. The SAML Relay State is used to store the postlogin_path
         # URI where the user is redirect after an successful SAML login
-        request.GET.update({
-            '__login': 'saml-login',
-            'postlogin_path': request.url,
-        })
+        request.GET.update(
+            {
+                "__login": "saml-login",
+                "postlogin_path": request.url,
+            }
+        )
 
         return self.get_saml_uri_from_request(request)
 
 
 class SAMLLogin(LogInTemplate, SAMLLogMixin):
-    """ Redirect automatically to SAML IdP server
+    """Redirect automatically to SAML IdP server
 
     This class override the default login page to always redirect to IdP server
 
@@ -115,12 +115,12 @@ class SAMLLogin(LogInTemplate, SAMLLogMixin):
     """
 
     __select__ = LogInTemplate.__select__ & anonymous_user()
-    __regid__ = 'login'
+    __regid__ = "login"
 
     priority = 50
 
     def call(self):
-        """ Call the current view
+        """Call the current view
 
         See Also
         --------
@@ -141,12 +141,12 @@ class SAMLLogout(LoggedOutTemplate, SAMLLogMixin):
     """
 
     __select__ = LoggedOutTemplate.__select__ & anonymous_user()
-    __regid__ = 'loggedout'
+    __regid__ = "loggedout"
 
     priority = 50
 
     def call(self):
-        """ Call the current view
+        """Call the current view
 
         See Also
         --------
@@ -157,7 +157,7 @@ class SAMLLogout(LoggedOutTemplate, SAMLLogMixin):
         super(SAMLLogout, self).call()
 
     def get_saml_uri_from_request(self, request):
-        """ Retrieve the SAML IdP server URL based on receiving request
+        """Retrieve the SAML IdP server URL based on receiving request
 
         Parameters
         ----------
@@ -179,11 +179,11 @@ class SAMLLogout(LoggedOutTemplate, SAMLLogMixin):
         # Use urlparse to only retrieve the beggining of the uri string
         uri = urlparse(saml_uri)
 
-        return '%s://%s' % (uri.scheme, uri.netloc)
+        return "%s://%s" % (uri.scheme, uri.netloc)
 
 
 def registration_callback(vreg):
-    """ Add SAML dedicated views inside the CubicWeb registry
+    """Add SAML dedicated views inside the CubicWeb registry
 
     Parameters
     ----------
